@@ -1,5 +1,5 @@
 from django.conf import settings as django_settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 import string
 
@@ -59,6 +59,9 @@ DEFAULTS = {
         'auth_token.authorization_request.backends.MobileDeviceAuthorizationRequestBackend',
     ],  # List of backends used for authorization request authentication.
     'MOBILE_DEVICE_SECRET_PASSWORD_LENGTH': 64,  # Default length for generated mobile device secret token
+    'EXPIRATION_DELTA': 0,  # Authorization token expiration will be extended, only if original expiration is at
+                            # least "X" seconds older, than new one (default: 0 seconds, i.e. always extend)
+    'TAKEOVER_ENABLED': True,  # Turns on/off takeover functionality
 }
 
 
